#ifndef GDHCPD_cancel_add_conf_button_clicked_H
#   define GDHCPD_cancel_add_conf_button_clicked_H

extern struct w *widgets;

void cancel_add_conf_button_clicked(struct w *widgets);

#endif
